@@ -1,10 +1,10 @@
 import requests 
 
-__version__ = "0.0.4"
+__version__ = "0.0.5"
 
 __url__ = "https://api.adviceslip.com/advice"
 
 def advice(name):
-    json_result = requests.get(self.url).json()
+    json_result = requests.get(__url__).json()
     advice_result = json_result["slip"]["advice"]
     return f"{name}, {advice_result}"
\ No newline at end of file
